1.0.0 API documentation: matrix_major_storage.hpp Source File

| 1.0.0 API documentation

matrix_major_storage.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependency:
17 #include "../glm.hpp"
18
19 #ifndef GLM_ENABLE_EXPERIMENTAL
20 # error "GLM: GLM_GTX_matrix_major_storage is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it."
21 #elif GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
22 # pragma message("GLM: GLM_GTX_matrix_major_storage extension included")
23 #endif
24
25 namespace glm
26 {
29
32 template<typename T, qualifier Q>
33 GLM_FUNC_DECL mat<2, 2, T, Q> rowMajor2(
34 vec<2, T, Q> const& v1,
35 vec<2, T, Q> const& v2);
36
39 template<typename T, qualifier Q>
40 GLM_FUNC_DECL mat<2, 2, T, Q> rowMajor2(
41 mat<2, 2, T, Q> const& m);
42
45 template<typename T, qualifier Q>
46 GLM_FUNC_DECL mat<3, 3, T, Q> rowMajor3(
47 vec<3, T, Q> const& v1,
48 vec<3, T, Q> const& v2,
49 vec<3, T, Q> const& v3);
50
53 template<typename T, qualifier Q>
54 GLM_FUNC_DECL mat<3, 3, T, Q> rowMajor3(
55 mat<3, 3, T, Q> const& m);
56
59 template<typename T, qualifier Q>
60 GLM_FUNC_DECL mat<4, 4, T, Q> rowMajor4(
61 vec<4, T, Q> const& v1,
62 vec<4, T, Q> const& v2,
63 vec<4, T, Q> const& v3,
64 vec<4, T, Q> const& v4);
65
68 template<typename T, qualifier Q>
69 GLM_FUNC_DECL mat<4, 4, T, Q> rowMajor4(
70 mat<4, 4, T, Q> const& m);
71
74 template<typename T, qualifier Q>
75 GLM_FUNC_DECL mat<2, 2, T, Q> colMajor2(
76 vec<2, T, Q> const& v1,
77 vec<2, T, Q> const& v2);
78
81 template<typename T, qualifier Q>
82 GLM_FUNC_DECL mat<2, 2, T, Q> colMajor2(
83 mat<2, 2, T, Q> const& m);
84
87 template<typename T, qualifier Q>
88 GLM_FUNC_DECL mat<3, 3, T, Q> colMajor3(
89 vec<3, T, Q> const& v1,
90 vec<3, T, Q> const& v2,
91 vec<3, T, Q> const& v3);
92
95 template<typename T, qualifier Q>
96 GLM_FUNC_DECL mat<3, 3, T, Q> colMajor3(
97 mat<3, 3, T, Q> const& m);
98
101 template<typename T, qualifier Q>
102 GLM_FUNC_DECL mat<4, 4, T, Q> colMajor4(
103 vec<4, T, Q> const& v1,
104 vec<4, T, Q> const& v2,
105 vec<4, T, Q> const& v3,
106 vec<4, T, Q> const& v4);
107
110 template<typename T, qualifier Q>
111 GLM_FUNC_DECL mat<4, 4, T, Q> colMajor4(
112 mat<4, 4, T, Q> const& m);
113
115 }//namespace glm
116
117 #include "matrix_major_storage.inl"
glm::rowMajor2
GLM_FUNC_DECL mat< 2, 2, T, Q > rowMajor2(mat< 2, 2, T, Q > const &m)
Build a row major matrix from other matrix.
glm::colMajor3
GLM_FUNC_DECL mat< 3, 3, T, Q > colMajor3(mat< 3, 3, T, Q > const &m)
Build a column major matrix from other matrix.
glm::rowMajor3
GLM_FUNC_DECL mat< 3, 3, T, Q > rowMajor3(mat< 3, 3, T, Q > const &m)
Build a row major matrix from other matrix.
glm::rowMajor4
GLM_FUNC_DECL mat< 4, 4, T, Q > rowMajor4(mat< 4, 4, T, Q > const &m)
Build a row major matrix from other matrix.
glm::colMajor4
GLM_FUNC_DECL mat< 4, 4, T, Q > colMajor4(mat< 4, 4, T, Q > const &m)
Build a column major matrix from other matrix.
glm::colMajor2
GLM_FUNC_DECL mat< 2, 2, T, Q > colMajor2(mat< 2, 2, T, Q > const &m)
Build a column major matrix from other matrix.